%define uname         QtAV

%define major           1
%define libname         %mklibname %{name} %{major}
%define libname_widgets %mklibname %{name}widgets %{major}
%define develname       %mklibname %{name} -d

Name:           qtav
Version:        1.12.0
Release:        %mkrel 1
Summary:        Qt5 multimedia framework
License:        LGPLv2+ and GPLv3
Group:          Video/Players
Url:            http://qtav.org/
Source0:        https://github.com/wang-bin/QtAV/archive/v%{version}/%{uname}-%{version}.tar.gz

BuildRequires:  imagemagick
BuildRequires:  kf5-macros
BuildRequires:  portaudio-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(uchardet)
BuildRequires:  pkgconfig(xv)

Provides:       %{uname} = %{version}-%{release}

%description
QtAV is a multimedia playback library based on Qt and FFmpeg. It can help
you to write a player with less effort than ever before.

Features include:
   * Hardware decoding suppprt: DXVA2, VAAPI, VDA, CedarX, CUDA
   * OpenGL and ES2 support for Hi10P and other 16-bit YUV videos
   * Real time preview
   * Video capture in rgb and yuv format
   * OSD and custom filters
   * Subtitle
   * Transform video using GraphicsItemRenderer. (rotate, shear, etc)
   * Playing frame by frame (currently support forward playing)
   * Playback speed control
   * Variant streams: locale file, http, rtsp, etc.
   * Audio channel, tracks and external audio tracks
   * Dynamically change render engine when playing
   * Multiple video outputs for 1 player
   * Region of interest(ROI), i.e. video cropping
   * Video eq: brightness, contrast, saturation, hue
   * QML support as a plugin. Most playback APIs are compatible with
     QtMultiMedia module

%files
%doc Changelog README*
%{_qt5_bindir}/Player
%{_qt5_bindir}/QMLPlayer
%{_datadir}/applications/Player.desktop
%{_datadir}/applications/QMLPlayer.desktop
%{_iconsdir}/hicolor/scalable/apps/%{uname}.svg
%dir %{_qt5_qml}/%{uname}
%{_qt5_qml}/%{uname}/Video.qml
%{_qt5_qml}/%{uname}/libQmlAV.so
%{_qt5_qml}/%{uname}/plugins.qmltypes
%{_qt5_qml}/%{uname}/qmldir

#----------------------------------------------------

%package -n     %{libname}
Summary:        QtAV library
Group:          System/Libraries

%description -n %{libname}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the QtAV library.

%files -n %{libname}
%{_qt5_libdir}/lib%{uname}.so.%{major}{,.*}

#----------------------------------------------------

%package -n     %{libname_widgets}
Summary:        QtAV Widgets module
Group:          System/Libraries

%description -n %{libname_widgets}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains a set of widgets to play media.

%files -n %{libname_widgets}
%{_qt5_libdir}/lib%{uname}Widgets.so.%{major}{,.*}

#----------------------------------------------------

%package -n     %{develname}
Summary:        QtAV development files
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_widgets} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{uname}-devel = %{version}-%{release}
Provides:       %{name}widgets-devel = %{version}-%{release}
Provides:       %{uname}Widgets-devel = %{version}-%{release}

%description -n %{develname}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the header development files for building some QtAV
applications using QtAV headers.

%files -n %{develname}
%{_qt5_includedir}/%{uname}/
%{_qt5_includedir}/%{uname}Widgets/
%{_qt5_libdir}/lib%{uname}.so
%{_qt5_libdir}/lib%{uname}Widgets.so
%{_qt5_libdir}/lib%{uname}.prl
%{_qt5_libdir}/lib%{uname}Widgets.prl
%{_qt5_prefix}/mkspecs/features/av.prf
%{_qt5_prefix}/mkspecs/features/avwidgets.prf
%{_kf5_mkspecsdir}/qt_lib_av.pri
%{_kf5_mkspecsdir}/qt_lib_av_private.pri
%{_kf5_mkspecsdir}/qt_lib_avwidgets.pri
%{_kf5_mkspecsdir}/qt_lib_avwidgets_private.pri

#----------------------------------------------------

%prep
%setup -q -n %{uname}-%{version}
%autopatch -p1

%build
%qmake_qt5 "CONFIG+=no_rpath recheck"
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

find %{buildroot} -name '*.a' -delete

# duplicate files
rm -rf %{buildroot}%{_datadir}/doc


%changelog
* Sun Jun 25 2017 akien <akien> 1.12.0-1.mga6
+ Revision: 1108425
- Version 1.12.0

* Tue May 02 2017 akien <akien> 1.11.0-4.mga6
+ Revision: 1098372
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 1.11.0-3.mga6
+ Revision: 1090249
- Rebuild for ffmpeg 3.2.4

* Wed Jan 11 2017 luigiwalser <luigiwalser> 1.11.0-2.mga6
+ Revision: 1081054
- rebuild for libass

* Sat Oct 29 2016 akien <akien> 1.11.0-1.mga6
+ Revision: 1064040
- Version 1.11.0

* Sun May 29 2016 akien <akien> 1.10.0-2.mga6
+ Revision: 1019320
- Fix patch renaming the player.desktop to uppercase

* Sat May 28 2016 akien <akien> 1.10.0-1.mga6
+ Revision: 1019187
- imported package qtav

